summaryrefslogtreecommitdiffstats
path: root/libkdeedu/extdate/extdatetbl.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-04 02:22:38 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-04 02:22:38 +0000
commit98a12d05a48814bec3870b9a6d5865475cfa1c95 (patch)
treea711801e47696fb0cf162abd7330e0b5b480ba39 /libkdeedu/extdate/extdatetbl.cpp
parent421a1845137c7c396b5d03bce53237fcb149d602 (diff)
downloadtdeedu-98a12d05a48814bec3870b9a6d5865475cfa1c95.tar.gz
tdeedu-98a12d05a48814bec3870b9a6d5865475cfa1c95.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1211429 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdeedu/extdate/extdatetbl.cpp')
-rw-r--r--libkdeedu/extdate/extdatetbl.cpp58
1 files changed, 29 insertions, 29 deletions
diff --git a/libkdeedu/extdate/extdatetbl.cpp b/libkdeedu/extdate/extdatetbl.cpp
index ca403a68..213ee277 100644
--- a/libkdeedu/extdate/extdatetbl.cpp
+++ b/libkdeedu/extdate/extdatetbl.cpp
@@ -124,7 +124,7 @@ ExtDateTable::ExtDateTable(TQWidget *parent, ExtDate date_, const char* name, WF
if(!date_.isValid())
{
kdDebug() << "ExtDateTable ctor: WARNING: Given date is invalid, using current date." << endl;
- date_=ExtDate::currentDate();
+ date_=ExtDate::tqcurrentDate();
}
setFocusPolicy( TQWidget::StrongFocus );
setNumRows(7); // 6 weeks max + headline
@@ -204,7 +204,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
normalday=false;
TQBrush brushTitle();
- TQBrush brushInvertTitle(colorGroup().base());
+ TQBrush brushInvertTitle(tqcolorGroup().base());
TQColor titleColor(isEnabled()?( KGlobalSettings::activeTitleColor() ):( KGlobalSettings::inactiveTitleColor() ) );
TQColor textColor(isEnabled()?( KGlobalSettings::activeTextColor() ):( KGlobalSettings::inactiveTextColor() ) );
if (!normalday)
@@ -221,7 +221,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
}
painter->drawText(0, 0, w, h-1, AlignCenter,
d->calendar->weekDayName(daynum, true), -1, &rect);
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
painter->moveTo(0, h-1);
painter->lineTo(w-1, h-1);
// ----- draw the weekday:
@@ -238,7 +238,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
// ° painting a day of the previous month or
// ° painting a day of the following month
// TODO: don't hardcode gray here! Use a color with less contrast to the background than normal text.
- painter->setPen( colorGroup().mid() );
+ painter->setPen( tqcolorGroup().mid() );
// painter->setPen(gray);
} else { // paint a day of the current month
if ( d->useCustomColors )
@@ -263,9 +263,9 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
}
painter->setPen( mode->fgColor );
} else
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
} else //if ( firstWeekDay < 4 ) // <- this doesn' make sense at all!
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
}
pen=painter->pen();
@@ -276,19 +276,19 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
if( ((offset+dy) == (pos+1)) && hasFocus())
{
// draw the currently selected date
- painter->setPen(colorGroup().highlight());
- painter->setBrush(colorGroup().highlight());
- pen=colorGroup().highlightedText();
+ painter->setPen(tqcolorGroup().highlight());
+ painter->setBrush(tqcolorGroup().highlight());
+ pen=tqcolorGroup().highlightedText();
} else {
painter->setBrush(paletteBackgroundColor());
painter->setPen(paletteBackgroundColor());
-// painter->setBrush(colorGroup().base());
-// painter->setPen(colorGroup().base());
+// painter->setBrush(tqcolorGroup().base());
+// painter->setPen(tqcolorGroup().base());
}
- if ( pCellDate == ExtDate::currentDate() )
+ if ( pCellDate == ExtDate::tqcurrentDate() )
{
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
}
if ( paintRect ) painter->drawRect(0, 0, w, h);
@@ -347,7 +347,7 @@ ExtDateTable::keyPressEvent( TQKeyEvent *e )
setDate(date.addDays(1));
return;
case Key_N:
- setDate(ExtDate::currentDate());
+ setDate(ExtDate::tqcurrentDate());
return;
case Key_Return:
case Key_Enter:
@@ -390,7 +390,7 @@ ExtDateTable::setFontSize(int size)
maxCell.setHeight(QMAX(maxCell.height(), rect.height()));
}
// ----- compare with a real wide number and add some space:
- rect=metrics.boundingRect(TQString::fromLatin1("88"));
+ rect=metrics.boundingRect(TQString::tqfromLatin1("88"));
maxCell.setWidth(QMAX(maxCell.width()+2, rect.width()));
maxCell.setHeight(QMAX(maxCell.height()+4, rect.height()));
}
@@ -494,7 +494,7 @@ ExtDateTable::setDate(const ExtDate& date_)
numDaysPrevMonth=d->calendar->daysInMonth(temp);
if(changed)
{
- repaintContents(false);
+ tqrepaintContents(false);
}
return true;
}
@@ -505,28 +505,28 @@ ExtDateTable::getDate() const
return date;
}
// what are those repaintContents() good for? (pfeiffer)
void ExtDateTable::focusInEvent( TQFocusEvent *e )
{
-// repaintContents(false);
+// tqrepaintContents(false);
TQGridView::focusInEvent( e );
}
void ExtDateTable::focusOutEvent( TQFocusEvent *e )
{
-// repaintContents(false);
+// tqrepaintContents(false);
TQGridView::focusOutEvent( e );
}
QSize
-ExtDateTable::sizeHint() const
+ExtDateTable::tqsizeHint() const
{
if(maxCell.height()>0 && maxCell.width()>0)
{
return TQSize(maxCell.width()*numCols()+2*frameWidth(),
(maxCell.height()+2)*numRows()+2*frameWidth());
} else {
- kdDebug() << "ExtDateTable::sizeHint: obscure failure - " << endl;
+ kdDebug() << "ExtDateTable::tqsizeHint: obscure failure - " << endl;
return TQSize(-1, -1);
}
}
@@ -554,7 +554,7 @@ void ExtDateTable::setCustomDatePainting(const ExtDate &date, const TQColor &fgC
mode->fgColor=fgColor;
mode->bgColor=bgColor;
- d->customPaintingModes.replace( date.toString(), mode );
+ d->customPaintingModes.tqreplace( date.toString(), mode );
d->useCustomColors=true;
update();
}
@@ -617,7 +617,7 @@ ExtDateInternalWeekSelector::setMaxWeek(int max)
}
// ### CFM To avoid binary incompatibility.
// In future releases, remove this and replace by a ExtDate
// private member, needed in ExtDateInternalMonthPicker::paintCell
class ExtDateInternalMonthPicker::ExtDateInternalMonthPrivate {
public:
@@ -677,7 +677,7 @@ ExtDateInternalMonthPicker::ExtDateInternalMonthPicker
}
QSize
-ExtDateInternalMonthPicker::sizeHint() const
+ExtDateInternalMonthPicker::tqsizeHint() const
{
return TQSize((max.width()+6)*numCols()+2*frameWidth(),
(max.height()+6)*numRows()+2*frameWidth());
@@ -779,7 +779,7 @@ ExtDateInternalMonthPicker::contentsMouseMoveEvent(TQMouseEvent *e)
updateCell( row, col /*, false */ ); // mark the new active cell
}
}
- if ( tmpRow > -1 ) // repaint the former active cell
+ if ( tmpRow > -1 ) // tqrepaint the former active cell
updateCell( tmpRow, tmpCol /*, true */ );
}
}
@@ -888,7 +888,7 @@ KPopupFrame::keyPressEvent(TQKeyEvent* e)
if(e->key()==Key_Escape)
{
result=0; // rejected
- qApp->exit_loop();
+ tqApp->exit_loop();
}
}
@@ -896,7 +896,7 @@ void
KPopupFrame::close(int r)
{
result=r;
- qApp->exit_loop();
+ tqApp->exit_loop();
}
void
@@ -947,8 +947,8 @@ int
KPopupFrame::exec(TQPoint pos)
{
popup(pos);
- repaint();
- qApp->enter_loop();
+ tqrepaint();
+ tqApp->enter_loop();
hide();
return result;
}
@@ -505,28 +505,28 @@ ExtDateTable::getDate() const
return date;
}
-// what are those repaintContents() good for? (pfeiffer)
+// what are those tqrepaintContents() good for? (pfeiffer)
void ExtDateTable::focusInEvent( TQFocusEvent *e )
{
@@ -617,7 +617,7 @@ ExtDateInternalWeekSelector::setMaxWeek(int max)
}
// ### CFM To avoid binary incompatibility.
-// In future releases, remove this and replace by a ExtDate
+// In future releases, remove this and tqreplace by a ExtDate
// private member, needed in ExtDateInternalMonthPicker::paintCell
class ExtDateInternalMonthPicker::ExtDateInternalMonthPrivate {